==> 0.0.1.tar.gz: lib/src/app_viewmodel.dart <==
import 'package:flutter/material.dart';
import 'package:modular_system_core/modular_system_core.dart';

enum AppTextType {
  title,
  subtitle,
  data,
  label,
}

class AppViewModel {
  AppViewModel({
    required this.colorScheme,
    required this.textSize,
    required this.loaderBuilder,
  });

  ColorScheme colorScheme;
  AppTextSize textSize;
  Widget Function(AppViewModel appViewModel) loaderBuilder;
  AppEvents events = AppEvents();

  Widget loading() => loaderBuilder(this);

  TextStyle primaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getPrimaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle secondaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getSecondaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle tertiaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getTertiaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle tertiaryContainerTextStyle(
      [AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getTertiaryContainerTextStyleFrom(colorScheme, textType);
  }

  TextStyle backgroundTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getBackgroundTextStyleFrom(colorScheme, textType);
  }

  TextStyle errorTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getErrorTextStyleFrom(colorScheme, textType);
  }

  TextStyle errorContainerTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getErrorContainerTextStyleFrom(colorScheme, textType);
  }
}

class AppEvents {
  AppEvent errorEvent = AppEvent();
  AppEvent infoEvent = AppEvent();
  AppMonoEvent<ColorScheme, void> colorSchemeEvent = AppMonoEvent();
  AppMonoEvent<AppBottomSheet, Future<dynamic>> bottomSheetEvent =
      AppMonoEvent();
}

class AppTextSize {
  AppTextSize({
    required this.title,
    required this.subtitle,
    required this.data,
    required this.label,
  });

  double title;
  double subtitle;
  double data;
  double label;
}

class AppTextStyleProvider {
  AppTextStyleProvider(this.textSize);

  AppTextSize textSize;

  TextStyle getPrimaryTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onPrimary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getSecondaryTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onSecondary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getTertiaryTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onTertiary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getTertiaryContainerTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onTertiaryContainer,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getBackgroundTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onBackground,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getErrorTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onError,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getErrorContainerTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onErrorContainer,
      fontSize: getFontSizeFrom(textType),
    );
  }

  double getFontSizeFrom(AppTextType textType) {
    switch (textType) {
      case AppTextType.title:
        return textSize.title;
      case AppTextType.subtitle:
        return textSize.subtitle;
      case AppTextType.label:
        return textSize.label;
      case AppTextType.data:
        return textSize.data;
      default:
        return 22;
    }
  }
}

class AppBottomSheet {
  AppBottomSheet({
    required this.child,
    this.shape = const ContinuousRectangleBorder(),
  });

  Widget child;
  ShapeBorder shape;

  factory AppBottomSheet.empitySquared() {
    return AppBottomSheet(
      child: Container(),
      shape: const RoundedRectangleBorder(),
    );
  }

  factory AppBottomSheet.empityRounded() {
    return AppBottomSheet(
      child: Container(),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(80),
          topRight: Radius.circular(80),
        ),
      ),
    );
  }

  factory AppBottomSheet.squared(Widget child) {
    return AppBottomSheet(
      child: child,
      shape: const RoundedRectangleBorder(),
    );
  }

  factory AppBottomSheet.rounded(Widget child) {
    return AppBottomSheet(
      child: child,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(80),
          topRight: Radius.circular(80),
        ),
      ),
    );
  }
}

==> 0.1.2.tar.gz: lib/src/app_viewmodel.dart <==
import 'package:flutter/material.dart';
import 'package:modular_system_core/modular_system_core.dart';

enum AppTextType {
  title,
  subtitle,
  data,
  label,
}

class AppViewModel {
  AppViewModel({
    required this.colorScheme,
    required this.textSize,
    required this.loaderBuilder,
  });

  ColorScheme colorScheme;
  AppTextSize textSize;
  Widget Function(AppViewModel appViewModel) loaderBuilder;
  AppEvents appEvents = AppEvents();

  Widget loading() => loaderBuilder(this);

  TextStyle primaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getPrimaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle secondaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getSecondaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle tertiaryTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getTertiaryTextStyleFrom(colorScheme, textType);
  }

  TextStyle tertiaryContainerTextStyle(
      [AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getTertiaryContainerTextStyleFrom(colorScheme, textType);
  }

  TextStyle backgroundTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getBackgroundTextStyleFrom(colorScheme, textType);
  }

  TextStyle errorTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getErrorTextStyleFrom(colorScheme, textType);
  }

  TextStyle errorContainerTextStyle([AppTextType textType = AppTextType.data]) {
    return AppTextStyleProvider(textSize)
        .getErrorContainerTextStyleFrom(colorScheme, textType);
  }
}

class AppEvents {
  AppEvent errorEvent = AppEvent();
  AppEvent infoEvent = AppEvent();
  AppMonoEvent<ColorScheme, void> colorSchemeEvent = AppMonoEvent();
  AppMonoEvent<AppBottomSheet, Future<dynamic>> bottomSheetEvent =
      AppMonoEvent();
}

class AppTextSize {
  AppTextSize({
    required this.title,
    required this.subtitle,
    required this.data,
    required this.label,
  });

  double title;
  double subtitle;
  double data;
  double label;
}

class AppTextStyleProvider {
  AppTextStyleProvider(this.textSize);

  AppTextSize textSize;

  TextStyle getPrimaryTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onPrimary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getSecondaryTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onSecondary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getTertiaryTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onTertiary,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getTertiaryContainerTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onTertiaryContainer,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getBackgroundTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onBackground,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getErrorTextStyleFrom(ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onError,
      fontSize: getFontSizeFrom(textType),
    );
  }

  TextStyle getErrorContainerTextStyleFrom(
      ColorScheme scheme, AppTextType textType) {
    return TextStyle(
      color: scheme.onErrorContainer,
      fontSize: getFontSizeFrom(textType),
    );
  }

  double getFontSizeFrom(AppTextType textType) {
    switch (textType) {
      case AppTextType.title:
        return textSize.title;
      case AppTextType.subtitle:
        return textSize.subtitle;
      case AppTextType.label:
        return textSize.label;
      case AppTextType.data:
        return textSize.data;
      default:
        return 22;
    }
  }
}

class AppBottomSheet {
  AppBottomSheet({
    required this.child,
    this.shape = const ContinuousRectangleBorder(),
  });

  Widget child;
  ShapeBorder shape;

  factory AppBottomSheet.empitySquared() {
    return AppBottomSheet(
      child: Container(),
      shape: const RoundedRectangleBorder(),
    );
  }

  factory AppBottomSheet.empityRounded() {
    return AppBottomSheet(
      child: Container(),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(80),
          topRight: Radius.circular(80),
        ),
      ),
    );
  }

  factory AppBottomSheet.squared(Widget child) {
    return AppBottomSheet(
      child: child,
      shape: const RoundedRectangleBorder(),
    );
  }

  factory AppBottomSheet.rounded(Widget child) {
    return AppBottomSheet(
      child: child,
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(80),
          topRight: Radius.circular(80),
        ),
      ),
    );
  }
}
